/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.bl;

import java.util.List;

// ---------------------------------------------------------------------------
// Implementation
// ---------------------------------------------------------------------------

/**
 * This interface defines the mapping between different model elements.
 */
public interface Mapping extends NamedElement {
    
    /**
     * Unique key of the mapping instance.
     * 
     * @return The unique key as String. 
     */
    public String getKey();

    /**
     * Specifies the mapping kind. E.g. 'ScopeMapping', 'InterfaceMapping', ...
     * 
     * @param kind The kind as String.
     */
    public void setKind(String kind);
    
    /**
     * Returns the mapping kind. E.g. 'ScopeMapping or InterfaceMapping'
     * 
     * @return Returns the kind as String.
     */
    public String getKind();

    /**
     * Verifies if this mapping object contains the given value.
     * 
     * @param value The value to search for.
     * @return True, if this mapping object contains the value. Otherwise, false.
     */
    public boolean containsValue(ModelElement value);
    
    /**
     * Returns all values contained in this object.
     * 
     * @return The values as flat list. 
     */
    public List<ModelElement> getValues();
    
    /**
     * Returns all values of the given class type.
     *  
     * @param value The class kind to search for.   
     * @param <T> The value can be any kind of Model Element.
     * @return The values as flat list.
     */
    public <T extends ModelElement> List<ModelElement> getValues(Class<T> value);
    
    /**
     * Adds a value to this mapping object.
     * 
     * @param value The value to be added.
     */
    public void addValue(ModelElement value);
    
    /**
     * Removes a value from this mapping object
     * 
     * @param value The value to be removed.
     */
    public void removeValue(ModelElement value);
}
// ---------------------------------------------------------------------------
// END OF FILE
// ---------------------------------------------------------------------------