/**
 *  @file   ModelElement.java
 *  @brief  ModelElement is base class for all DMOs.
 *  @author prometheus@btc-es.de
 *
 *  A ModelElements adds the unique identifiers to all DMO objects.
 *  Furthermore it allows saving of objects.
 *  Messages regarding a model elements can be retrieved.
 *
 *  --------------------------------------------------------- 
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision:  $
 *  --------------------------------
 */
package com.btc.ep.base.bl;


/**
 * A ModelElements adds the unique identifiers to all DMO objects.
 * Furthermore it allows saving of objects.
 * Messages regarding a model elements can be retrieved.
 */
public abstract interface ModelElement {

    /**
     * Get the Uniform Resource Identifier for this object.
     * 
     * @return Uniform Resource Identifier
     */
    public String getURI();

    /**
     * Get the Universally Unique Identifier for this object.
     * 
     * @return Universally Unique Identifier
     */
    public String getUid();
}