/**
 *  @file   ModelElementImpl.java
 *  @brief  ModelElement is base class for all DMOs.
 *  @author stefanh
 *
 *  A ModelElements adds the unique identifiers to all DMO objects.
 *  Furthermore it allows saving of objects.
 *  Messages regarding a model elements can be retrieved.
 *
 *  --------------------------------------------------------- 
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision:  $
 *  --------------------------------
 */
package com.btc.ep.base.bl.impl;

import java.util.UUID;

import com.btc.ep.base.bl.ModelElement;

/**
 * A ModelElements adds the unique identifiers to all DMO objects.
 * Furthermore it allows saving of objects.
 * Messages regarding a model elements can be retrieved.
 */
public abstract class ModelElementImpl implements ModelElement {

    private String uid;

    /**
     * JPA Entity Default constructor
     * <p>The default constructor must be a public or protected zero-argument constructor.</p>
     */
    protected ModelElementImpl() {
        this.uid = UUID.randomUUID().toString().toUpperCase();
    }

    @Override
    public int hashCode() {
        if (uid == null) {
            return super.hashCode();
        }

        return uid.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj instanceof ModelElement && this.getUid() != null) {
            return this.getUid().equals(((ModelElement)obj).getUid());
        }

        return super.equals(obj);
    }

    @Override
    public String getURI() {
        throw new UnsupportedOperationException();
    }

    @Override
    public final String getUid() {
        return this.uid;
    }
}
