/**
 *  @file      NLRequirement.java
 *  @author    stefanh
 *
 *  Copyright (c)
 *  BTC Embedded Systems AG
 *  Oldenburg, Germany
 *
 *  --------------------------------
 *  $Author: stefanh $
 *  $Date: 2012-12-11 20:08:30 +0100 (Di, 11 Dez 2012) $
 *  $Rev: 128887 $
 *  --------------------------------
 */
package com.btc.ep.requirement.bl;

import com.btc.ep.base.bl.DescribableElement;

/**
 * Domain Model object representing a natural language requirement usually
 * coming from external requirement management tools.
 */
public interface Requirement extends DescribableElement {

    /**
     * Returns the requirement source containing this requirement
     * 
     * @return the requirement source object
     */
    public RequirementsSource getRequirementsSource();

    /**
     * Returns the requirement identifier (e.g. a chapter number within DOORS).
     * 
     * @return the identifier string.
     */
    public String getIdentifier();

    /**
     * Sets the requirement identifier.
     * 
     * @param identifier
     *            the identifier value
     */
    public void setIdentifier(String identifier);

    /**
     * An external URL to be used to open the requirement within its originating
     * requirement management tool.
     * 
     * @return the url string
     */
    public String getURL();

    /**
     * Sets the URL to be used to open this requirement within the external
     * requirement management tool.
     * 
     * @param url
     *            the URL string.
     */
    public void setURL(String url);

    /**
     * Returns whether this requirement has been removed within the requirement
     * management tool.
     * 
     * @return true, if removed, false otherwise
     */
    public boolean isRemoved();

    /**
     * Marks that this requirement has been removed within the requirement
     * management tool.
     * 
     * @param removed
     *            true, if removed, false otherwise
     */
    public void setRemoved(boolean removed);
}
