package com.btc.ep.requirement.bl;

import java.util.List;
import java.util.Map;

import com.btc.ep.base.bl.NamedElement;

/**
 * This interface describes a requirements source, a container for requirements
 * stemming from the same source. It encapsulates the requirements themselves as
 * well as the relevant meta-data for their source.
 * 
 * @author Stefan Husler
 * @author Andreas Eggers
 */
public interface RequirementsSource extends NamedElement {

    /**
     * Retrieves the setting value for the given key.
     *
     * @param key
     *            for which the setting shall be retrieved.
     * @return the value of the setting.
     */
    public String getSetting(String key);

    /**
     * Retrieves all settings stored for this requirement source.
     *
     * @return a key-value map of the settings.
     */
    public Map<String, String> getSettings();

    /**
     * Adds a setting under the given key with the given value.
     *
     * @param key
     *            under which to store the setting.
     * @param value
     *            of the setting.
     */
    public void addSetting(String key, String value);

    /**
     * Sets the kind of this requirement source.
     * 
     * @param kind
     */
    public void setKind(String kind);

    /**
     * Gets the kind of this requirement source. TODO: Concretize this comment
     * (maybe with some examples, which return values to expect and who defines
     * them).
     *
     * @param the
     *            kind of this source.
     */
    public String getKind();

    /**
     * Gets all requirements from this source.
     *
     * @return the list of requirements from this source.
     */
    public List<Requirement> getRequirements();

    /**
     * Adds a requirement to this source.
     *
     * @param req
     *            to be added.
     */
    public void addRequirement(Requirement req);

    /**
     * Returns a requirement object for this requirement source object that has
     * the given requirement name.
     *
     * @param name
     *            the requirement name to search for
     * @return the corresponding reuqirement object or null, if there is none
     */
    public Requirement getRequirementByName(String name);
}
